flatspin
========

flatspin is a GPU-accelerated simulator for systems of interacting mesoscopic
spins (nanomagnets) arranged on a 2D lattice, also known as artificial spin ice
(ASI). flatspin can simulate realistic dynamics of millions of magnets within
practical time frames.

flatspin is written in Python and uses OpenCL to accelerate the simulations on
the GPU.


Installing
----------

Install and update using ``pip``:

.. code-block:: text

    pip install -U flatspin


Getting started
---------------

Once installed, head over to the `User Manual`_ to get started.

.. _User Manual: https://flatspin.readthedocs.io/en/latest/quickstart.html


Links
-----

* Website: https://flatspin.gitlab.io
* Documentation: https://flatspin.readthedocs.io/en/latest
* Releases: https://pypi.org/project/flatspin
* Code: https://gitlab.com/flatspin/flatspin
* Issue tracker: https://gitlab.com/flatspin/flatspin/issues

.. _pip: https://pip.pypa.io/en/stable/quickstart/
